@@ -1,3 +1,6 @@
+# SPDX-License-Identifier: BSD-3-Clause
+# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+
 import h5py
 import numpy as np
 import pytest
@@ -70,7 +73,7 @@ def test_nxobject_log(nxroot):
     assert sc.identical(log[...], da)
 
 
-def test_nxobject_log_length_1(nxroot):
+def test_nxlog_length_1(nxroot):
     da = sc.DataArray(
         sc.array(dims=['time'], values=[1.1]),
         coords={
@@ -85,6 +88,77 @@ def test_nxobject_log_length_1(nxroot):
     assert sc.identical(log[...], da)
 
 
+def test_nxlog_length_1_two_dims_no_time_squeezes_all_dims(nxroot):
+    da = sc.DataArray(
+        sc.array(dims=['time', 'ignored'], values=[[1.1]]),
+        coords={
+            'time':
+            sc.epoch(unit='ns') +
+            sc.array(dims=['time'], unit='s', values=[4.4]).to(unit='ns', dtype='int64')
+        })
+    log = nxroot['entry'].create_class('log', NX_class.NXlog)
+    log['value'] = da.data
+    assert sc.identical(log[...], sc.DataArray(sc.scalar(1.1)))
+
+
+def test_nxlog_length_1_two_dims_with_time_squeezes_inner_dim(nxroot):
+    da = sc.DataArray(
+        sc.array(dims=['time', 'ignored'], values=[[1.1]]),
+        coords={
+            'time':
+            sc.epoch(unit='ns') +
+            sc.array(dims=['time'], unit='s', values=[4.4]).to(unit='ns', dtype='int64')
+        })
+    log = nxroot['entry'].create_class('log', NX_class.NXlog)
+    log['value'] = da.data
+    log['time'] = da.coords['time'] - sc.epoch(unit='ns')
+    assert sc.identical(log[...], da['ignored', 0])
+
+
+def test_nxlog_axes_replaces_time_dim(nxroot):
+    da = sc.DataArray(
+        sc.array(dims=['time', 'ignored'], values=[[1.1]]),
+        coords={
+            'time':
+            sc.epoch(unit='ns') +
+            sc.array(dims=['time'], unit='s', values=[4.4]).to(unit='ns', dtype='int64')
+        })
+    log = nxroot['entry'].create_class('log', NX_class.NXlog)
+    log.attrs['axes'] = ['yy', 'xx']
+    log['value'] = da.data
+    log['time'] = da.coords['time'] - sc.epoch(unit='ns')
+    expected = sc.DataArray(sc.array(dims=['yy', 'xx'], values=[[1.1]]),
+                            coords={'time': da.coords['time'].squeeze()})
+    assert sc.identical(log[...], expected)
+
+
+def test_nxlog_three_dims_with_time_of_length_1(nxroot):
+    da = sc.DataArray(
+        sc.array(dims=['time', 'a', 'b'], values=np.arange(9.).reshape(1, 3, 3)),
+        coords={
+            'time':
+            sc.epoch(unit='ns') +
+            sc.array(dims=['time'], unit='s', values=[4.4]).to(unit='ns', dtype='int64')
+        })
+    log = nxroot['entry'].create_class('log', NX_class.NXlog)
+    log['value'] = da.data
+    log['time'] = da.coords['time'] - sc.epoch(unit='ns')
+    loaded = log[...]
+    assert sc.identical(
+        loaded.data,
+        sc.array(dims=['time', 'dim_1', 'dim_2'], values=np.arange(9.).reshape(1, 3,
+                                                                               3)))
+
+
+def test_nxlog_with_shape_0(nxroot):
+    da = sc.DataArray(sc.ones(dims=['time', 'ignored'], shape=(0, 1)),
+                      coords={'time': sc.ones(dims=['time'], shape=(0, ), unit='s')})
+    log = nxroot['entry'].create_class('log', NX_class.NXlog)
+    log['value'] = da.data
+    log['time'] = da.coords['time']
+    assert sc.identical(log[...], da['ignored', 0])
+
+
 def test_nxobject_event_data(nxroot):
     event_data = nxroot['entry'].create_class('events_0', NX_class.NXevent_data)
     assert event_data.nx_class == NX_class.NXevent_data
@@ -289,6 +363,16 @@ def test_negative_event_index_converted_to_num_event(nxroot):
     assert events.bins.size().values[3] == 0
 
 
+def test_bad_event_index_raises_IndexError(nxroot):
+    event_data = nxroot['entry'].create_class('events_0', NX_class.NXevent_data)
+    event_data['event_id'] = sc.array(dims=[''], unit=None, values=[1, 2, 4, 1, 2])
+    event_data['event_time_offset'] = sc.array(dims=[''], unit='s', values=[0, 0, 0, 0])
+    event_data['event_time_zero'] = sc.array(dims=[''], unit='s', values=[1, 2, 3, 4])
+    event_data['event_index'] = sc.array(dims=[''], unit=None, values=[0, 3, 3, 666])
+    with pytest.raises(IndexError):
+        nxroot['entry/events_0'][...]
+
+
 def create_event_data_without_event_id(group):
     group['event_time_offset'] = sc.array(dims=[''],
                                           unit='s',
